==> larus_board-0.9.3.tbz: larus_board-0.9.3/lb_private/lang/de/overview.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'all_posts_are_marked_as_read'=>'Alle Beiträge wurden als gelesen markiert.',
'cachemgr_purge_acl'=>'ACL-Zwischenspeicher löschen',
'cachemgr_purge_all'=>'Gesamten Zwischenspeicher löschen',
'cachemgr_purge_main'=>'Haupt-Zwischenspeicher löschen',
'cachemgr_purge_post'=>'Beitrag-Zwischenspeicher löschen',
'cachemgr_purge_topic'=>'Themen-Zeischenspeicher löschen',
'cachemgr_purge_tpl'=>'Vorlagen-Zwischenspeicher löschen',
'cachemgr_purge_user'=>'Benutzer-Zwischenspeicher löschen',
'cachemgr_success'=>'Der ausgewählte Bereich des Zwischenspeichers wurde gelöscht.',
'cache_manager'=>'Zwischenspeicher-Manager',
'currently_no_calendar'=>'Wir haben noch keinen Kalender erstellt...',
'currently_no_tags'=>'Keine Stichwörter verfügbar...',
'currently_no_topics'=>'Zur Zeit gibt es keine Themen zum Lesen...',
'list_by_month'=>'Themen nach Monat auflisten',
'mark_posts_as_read'=>'Markiere alle Beiträge als gelesen',
'most_used_tags'=>'Unsere häufig gefragten Stichwörter',
'post_new_topic'=>'Ein neues Thema eröffnen',
'recent_topics'=>'Unsere jüngsten Themen',
'show_posts_from_today'=>'Alle heutigen Beiträge zeigen',
'unapproved'=>'nicht freigeschaltet',
'user_count'=>'Mitglieder'
);
?>

==> larus_board-0.9.5.tbz: larus_board-0.9.5/lb_private/lang/de/overview.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'all_posts_are_marked_as_read'=>'Alle Beiträge wurden als gelesen markiert.',
'cachemgr_purge_acl'=>'Zugriffsregeln-Zwischenspeicher löschen',
'cachemgr_purge_all'=>'Gesamten Zwischenspeicher löschen',
'cachemgr_purge_main'=>'Haupt-Zwischenspeicher löschen',
'cachemgr_purge_post'=>'Beitrag-Zwischenspeicher löschen',
'cachemgr_purge_topic'=>'Themen-Zeischenspeicher löschen',
'cachemgr_purge_tpl'=>'Vorlagen-Zwischenspeicher löschen',
'cachemgr_purge_user'=>'Benutzer-Zwischenspeicher löschen',
'cachemgr_success'=>'Der ausgewählte Bereich des Zwischenspeichers wurde gelöscht.',
'cache_manager'=>'Zwischenspeicher-Verwaltung',
'currently_no_calendar'=>'Wir haben noch keinen Kalender erstellt...',
'currently_no_tags'=>'Keine Stichwörter verfügbar...',
'currently_no_topics'=>'Zur Zeit gibt es keine Themen zum Lesen...',
'list_by_month'=>'Themen nach Monat auflisten',
'mark_posts_as_read'=>'Markiere alle Beiträge als gelesen',
'most_used_tags'=>'Unsere häufig gefragten Stichwörter',
'post_new_topic'=>'Ein neues Thema eröffnen',
'recent_topics'=>'Unsere jüngsten Themen',
'show_posts_from_today'=>'Alle heutigen Beiträge zeigen',
'unapproved'=>'nicht freigeschaltet',
'user_count'=>'Mitglieder'
);
?>
